Class: Google::Cloud::AlloyDB::V1alpha::Database

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/alloydb/v1alpha/resources.rb

Overview

Message describing Database object.

Instance Attribute Summary collapse

Instance Attribute Details

#character_type::String

Returns Optional. Immutable. lc_ctype for the database. Character classification (What is a letter? The upper-case equivalent?). Example values include "C", "POSIX", etc.

Returns:

  • (::String)

    Optional. Immutable. lc_ctype for the database. Character classification (What is a letter? The upper-case equivalent?). Example values include "C", "POSIX", etc.



1745
1746
1747
1748
# File 'proto_docs/google/cloud/alloydb/v1alpha/resources.rb', line 1745

class Database
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#charset::String

Returns Optional. Immutable. Charset for the database. This field can contain any PostgreSQL supported charset name. Example values include "UTF8", "SQL_ASCII", etc.

Returns:

  • (::String)

    Optional. Immutable. Charset for the database. This field can contain any PostgreSQL supported charset name. Example values include "UTF8", "SQL_ASCII", etc.



1745
1746
1747
1748
# File 'proto_docs/google/cloud/alloydb/v1alpha/resources.rb', line 1745

class Database
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#collation::String

Returns Optional. Immutable. lc_collate for the database. String sort order. Example values include "C", "POSIX", etc.

Returns:

  • (::String)

    Optional. Immutable. lc_collate for the database. String sort order. Example values include "C", "POSIX", etc.



1745
1746
1747
1748
# File 'proto_docs/google/cloud/alloydb/v1alpha/resources.rb', line 1745

class Database
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#database_template::String

Returns Input only. Immutable. Template of the database to be used for creating a new database.

Returns:

  • (::String)

    Input only. Immutable. Template of the database to be used for creating a new database.



1745
1746
1747
1748
# File 'proto_docs/google/cloud/alloydb/v1alpha/resources.rb', line 1745

class Database
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#is_template::Boolean

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Optional. Whether the database is a template database. Deprecated in favor of is_template_database.

Returns:

  • (::Boolean)

    Optional. Whether the database is a template database. Deprecated in favor of is_template_database.



1745
1746
1747
1748
# File 'proto_docs/google/cloud/alloydb/v1alpha/resources.rb', line 1745

class Database
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#is_template_database::Boolean

Returns Optional. Whether the database is a template database.

Returns:

  • (::Boolean)

    Optional. Whether the database is a template database.



1745
1746
1747
1748
# File 'proto_docs/google/cloud/alloydb/v1alpha/resources.rb', line 1745

class Database
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. Name of the resource in the form of projects/{project}/locations/{location}/clusters/{cluster}/databases/{database}.

Returns:

  • (::String)

    Identifier. Name of the resource in the form of projects/{project}/locations/{location}/clusters/{cluster}/databases/{database}.



1745
1746
1747
1748
# File 'proto_docs/google/cloud/alloydb/v1alpha/resources.rb', line 1745

class Database
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end