Class: Google::Cloud::AlloyDB::V1alpha::User

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/alloydb/v1alpha/resources.rb

Overview

Message describing User object.

Defined Under Namespace

Modules: UserType

Instance Attribute Summary collapse

Instance Attribute Details

#database_roles::Array<::String>

Returns Optional. List of database roles this user has. The database role strings are subject to the PostgreSQL naming conventions.

Returns:

  • (::Array<::String>)

    Optional. List of database roles this user has. The database role strings are subject to the PostgreSQL naming conventions.



1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
# File 'proto_docs/google/cloud/alloydb/v1alpha/resources.rb', line 1695

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum that details the user type.
  module UserType
    # Unspecified user type.
    USER_TYPE_UNSPECIFIED = 0

    # The default user type that authenticates via password-based
    # authentication.
    ALLOYDB_BUILT_IN = 1

    # Database user that can authenticate via IAM-Based authentication.
    ALLOYDB_IAM_USER = 2
  end
end

#keep_extra_roles::Boolean

Returns Input only. If the user already exists and it has additional roles, keep them granted.

Returns:

  • (::Boolean)

    Input only. If the user already exists and it has additional roles, keep them granted.



1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
# File 'proto_docs/google/cloud/alloydb/v1alpha/resources.rb', line 1695

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum that details the user type.
  module UserType
    # Unspecified user type.
    USER_TYPE_UNSPECIFIED = 0

    # The default user type that authenticates via password-based
    # authentication.
    ALLOYDB_BUILT_IN = 1

    # Database user that can authenticate via IAM-Based authentication.
    ALLOYDB_IAM_USER = 2
  end
end

#name::String (readonly)

Returns Output only. Name of the resource in the form of projects/{project}/locations/{location}/cluster/{cluster}/users/{user}.

Returns:

  • (::String)

    Output only. Name of the resource in the form of projects/{project}/locations/{location}/cluster/{cluster}/users/{user}.



1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
# File 'proto_docs/google/cloud/alloydb/v1alpha/resources.rb', line 1695

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum that details the user type.
  module UserType
    # Unspecified user type.
    USER_TYPE_UNSPECIFIED = 0

    # The default user type that authenticates via password-based
    # authentication.
    ALLOYDB_BUILT_IN = 1

    # Database user that can authenticate via IAM-Based authentication.
    ALLOYDB_IAM_USER = 2
  end
end

#password::String

Returns Input only. Password for the user.

Returns:

  • (::String)

    Input only. Password for the user.



1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
# File 'proto_docs/google/cloud/alloydb/v1alpha/resources.rb', line 1695

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum that details the user type.
  module UserType
    # Unspecified user type.
    USER_TYPE_UNSPECIFIED = 0

    # The default user type that authenticates via password-based
    # authentication.
    ALLOYDB_BUILT_IN = 1

    # Database user that can authenticate via IAM-Based authentication.
    ALLOYDB_IAM_USER = 2
  end
end

#user_type::Google::Cloud::AlloyDB::V1alpha::User::UserType

Returns Optional. Type of this user.

Returns:



1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
# File 'proto_docs/google/cloud/alloydb/v1alpha/resources.rb', line 1695

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum that details the user type.
  module UserType
    # Unspecified user type.
    USER_TYPE_UNSPECIFIED = 0

    # The default user type that authenticates via password-based
    # authentication.
    ALLOYDB_BUILT_IN = 1

    # Database user that can authenticate via IAM-Based authentication.
    ALLOYDB_IAM_USER = 2
  end
end